@@ -117,8 +117,7 @@ static void InsertNthWeightedPoint(PyArrayObject* points,
   double x = *GETPTR2D<double>(points, n, 0);
   double y = *GETPTR2D<double>(points, n, 1);
   double w = weighted ? *GETPTR2D<double>(points, n, 2) : 0.0;
-  int group_name = rel_homology ?
-                   static_cast<int>(*GETPTR2D<double>(points, n, 2 + weighted)) : -1;
+  int group_name = GroupName(2, points, n, weighted, rel_homology);
   points_vector->emplace_back(Weighted_point(Bare_point(x, y), w),
                               VertexInfo{static_cast<int>(n), group_name});
 }
