@@ -157,7 +157,7 @@ class Simplex(object):
         self.isvertex = alpha_simplex.isvertex()
 
     def __repr__(self):
-        return "alpha_filtration.Simplex(index={}, key={}, birth_radius={}".format(
+        return "alpha_filtration.Simplex(index={}, key={}, birth_radius={})".format(
             self.index, self.key, self.birth_radius
         )
 
