@@ -2,6 +2,7 @@ import numpy as np
 
 import homcloud.pict.tree as pict_tree
 import homcloud.paraview_interface as pv_interface
+import homcloud.plotly_3d as p3d
 from homcloud.spatial_searcher import SpatialSearcher
 from . import bitmap as bm
 
@@ -10,8 +11,7 @@ class BitmapPHTrees(object):
     """
     This class represents PH trees computed from a bitmap filtration.
 
-    You can create an instance of this class
-    by :meth:`PDList.dim_0_trees` or :meth:`PDList.codim_1_trees`.
+    You can create an instance of this class by :meth:`PDList.bitmap_phtrees`.
 
 
     Attributes:
@@ -252,6 +252,21 @@ class BitmapPHTrees(object):
 
         to_pvnode = to_paraview_node
 
+        def to_plotly3d_trace(self, color=None, name=""):
+            """
+            Constructs a plotly's trace object to visualize the volume
+
+            Args:
+                color (string or None): The name of the color
+                name (string): The name of the object
+
+            Returns:
+                plotly.graph_objects.Mesh3d: Plotly's trace object
+            """
+            return p3d.Voxels(self.volume(), color, name)
+
+        to_plotly3d = to_plotly3d_trace
+
     class StableVolume(object):
         """
         This class represents a stable volume in :class:`BitmapPHTrees`.
@@ -308,6 +323,21 @@ class BitmapPHTrees(object):
 
         to_pvnode = to_paraview_node
 
+        def to_plotly3d_trace(self, color=None, name=""):
+            """
+            Constructs a plotly's trace object to visualize the stable volume
+
+            Args:
+                color (string or None): The name of the color
+                name (string): The name of the object
+
+            Returns:
+                plotly.graph_objects.Mesh3d: Plotly's trace object
+            """
+            return p3d.Voxels(list(self.volume()), color, name)
+
+        to_plotly3d = to_plotly3d_trace
+
     @staticmethod
     def to_paraview_node_from_nodes(nodes, gui_name=None):
         """
@@ -330,6 +360,6 @@ class BitmapPHTrees(object):
         min, max = bm.volume_range(all_volume)
         bitmap = bm.volume_to_bitmap(all_volume, (min, max))
 
-        return pv_interface.VoxelData(bitmap, gui_name, min)
+        return pv_interface.VoxelData(bitmap, gui_name, min).threshold("value", (0.5, 1.0))
 
     to_pvnode_from_nodes = to_paraview_node_from_nodes
