@@ -4,6 +4,7 @@ from forwardable import forwardable
 
 import homcloud.optvol as optvol
 import homcloud.paraview_interface as pv_interface
+import homcloud.plotly_3d as p3d
 
 
 @forwardable()
@@ -221,6 +222,51 @@ class Volume(object):
         f.close()
         return pv_interface.VTK(f.name, gui_name, f).set_representation("Wireframe")
 
+    def to_plotly3d_trace(self, color="green", width=1, name=""):
+        """
+        Constructs a plotly's trace object to visualize the optimal volume
+
+        Args:
+            color (string or None): The name of the color
+            width (int): The width of the line
+            name (string): The name of the object
+
+        Returns:
+            plotly.graph_objects.Scatter3d: Plotly's trace object
+        """
+        if self.diagram.filtration_type == "alpha":
+            return p3d.Simplices(self.boundary(), color, width, name)
+        elif self.diagram.filtration_type == "cubical":
+            return p3d.Cubes(self.boundary(), color, width, name)
+        else:
+            raise(RuntimeError(f"{self.filtration_type} cannot be renderred"))
+
+    to_plotly3d = to_plotly3d_trace
+
+    def to_plotly3d_mesh(self, color="green", name=""):
+        """
+        Constructs a plotly's trace object to visualize the face of an optimal volume
+
+        Args:
+            color (string or None): The name of the color
+            name (string): The name of the object
+
+        Returns:
+            plotly.graph_objects.Mesh3d: Plotly's trace object
+        """
+        if self.diagram.filtration_type == "alpha":
+            if self.diagram.degree == 2:
+                return p3d.SimplicesMesh(self.boundary(), color, name)
+            elif self.diagram.degree == 1:
+                return p3d.SimplicesMesh(self.simplices(), color, name)
+            else:
+                raise(RuntimeError(f"dim {self.diagram.degree} volume is available for plotly"))
+        elif self.diagram.filtration_type == "cubical":
+            if self.diagram.degree == 2:
+                return p3d.CubesMesh(self.boundary(), color, name)
+        else:
+            raise(RuntimeError(f"{self.filtration_type} cannot be renderred"))
+
 
 @forwardable()
 class OptimalVolume(Volume):
