@@ -26,6 +26,7 @@ import homcloud.diagram as homdiag
 import homcloud.pict.optimal_one_cycle as pict_opt1cyc
 import homcloud.optimal_one_cycle as opt1cyc
 import homcloud.plot_PD_slice as plot_PD_slice
+import homcloud.graph_optimal_one_cycle as graph_opt1cyc
 from homcloud.spatial_searcher import SpatialSearcher
 
 from .distance_transform import distance_transform
@@ -34,6 +35,7 @@ from .optimal_volume import OptimalVolume, StableVolume
 from .exceptions import VolumeNotFound
 from .bitmap_optimal_1_cycle import BitmapOptimal1Cycle
 from .boundary_map_optimal_1_cycle import Optimal1Cycle
+from .graph_optimal_1_cycle import GraphOptimal1Cycle
 from .ph0_component import PH0Components
 
 
@@ -412,7 +414,7 @@ class PDList(object):
     def from_rips_filtration(distance_matrix, maxdim, maxvalue=np.inf,
                              simplicial=False, vertex_symbols=None,
                              algorithm=None, parallels=1, save_boundary_map=False,
-                             save_to=None):
+                             save_graph=False, save_cocycles=False, save_to=None):
         """
         Compute a PDList from a distance matrix by using Vietoris-Rips
         filtrations.
@@ -422,7 +424,7 @@ class PDList(object):
             maxdim (int): Maximal homology degree computed.
             maxvalue (float): Maximal distance for constructing a filtration.
                 All longer edges do not apper in the constructed filtration.
-            simplicial (bool): If True, construct a simplicial complex for 
+            simplicial (bool): If True, construct a simplicial complex for
                 :meth:`Pair.optimal_volume` (slow)
             vertex_symbols (list[string] or None): The names of vertices.
                 The names are used to represent some simplices, such as
@@ -444,6 +446,8 @@ class PDList(object):
                 if this parameter is True. The boundary map is used to
                 compute volume optimal cycles. This option is only available
                 if `simplicial` is True.
+            save_graph (bool):
+                The graph structure of rips filtration is saved in .pdgm file.
             save_to (string or None): The file path which the computation result is
                 saved into. You can load the saved data by
                 `homcloud.interface.PDList(FILE_PATH)`.
@@ -454,11 +458,12 @@ class PDList(object):
             The :class:`PDList` object computed from the distance matrix.
 
         """
+        assert not (simplicial and save_graph)
         dm = rips.DistanceMatrix(distance_matrix, maxdim, maxvalue, vertex_symbols)
         if simplicial:
             filtration = dm.build_simplicial_filtration(save_boundary_map)
         else:
-            filtration = dm.build_rips_filtration()
+            filtration = dm.build_rips_filtration(save_graph, save_cocycles)
 
         return PDList.compute_pd(PDList.FileType.PDGM, filtration, save_to,
                                  parallels, algorithm, True)
@@ -473,8 +478,8 @@ class PDList(object):
 
         Args:
             boundary (list of (int, list of int, list of int)):
-                list of (dim of cell, list of indices of, list of coefs)
-            levels (numpy.ndarray): level of each cell.
+                list of cells and their boundary information. (dim of cell, list of indices of, list of coefs)
+            levels (numpy.ndarray): level of each cell. **Cells should be ordered in level-increasing order**.
             symbols (list of string, None): The names of each cell.
             algorithm (string, nil): The name of the algorithm.
                 An appropriate algorithm is automatically selected if None is given.
@@ -490,6 +495,23 @@ class PDList(object):
 
         Returns:
             :class:`PDList`: The PDList computed from the boundary map.
+
+        Examples:
+            >>> import homcloud.interface as hc
+            >>>
+            >>> hc.PDList.from_boundary_information([
+            >>>     [0, [], []], [0, [], []], [0, [], []],  # theee 0-simplices
+            >>>     [1, [0, 1], [1, -1]], [1, [1, 2], [1, -1]], [1, [0, 2], [1, -1]],  # three 1-simplices
+            >>>     [2, [3, 4, 5], [1, 1, -1]],  # a 2-simplex
+            >>> ], [
+            >>>     -0.02, 0.01, 0.01,  # levels of 0-simplices
+            >>>     0.1, 0.2, 0.3,  # levels of 1-simplices
+            >>>     0.6  # level of the 2-simplex
+            >>> ], save_to="pd.pdgm"
+            >>> )
+            >>> pd1 = hc.PDList("pd.pdgm").dth_diagram(1)
+            >>> print(pd1.births)  # => [0.3]
+            >>> print(pd1.deaths)  # => [0.6]
         """
         assert len(boundary) == len(levels)
         assert symbols is None or len(symbols) == len(boundary)
@@ -622,10 +644,10 @@ class PD(object):
         birth_positions: Birth positions for birth-death pairs
         death_positions: Death positions for birth-death pairs
         essential_births (numpy.ndarray[num_of_ess_pairs]):
-            Birth times of essenatial birth-death pairs (birth-death pairs with
+            Birth times of essential birth-death pairs (birth-death pairs with
             infinite death time)
         essential_birth_positions:
-            Birth positions for essenatial birth-death pairs
+            Birth positions for essential birth-death pairs
     """
 
     def __init__(self, path, pd):
@@ -751,6 +773,22 @@ class PD(object):
         """
         return PD(None, pdgm.empty_pd())
 
+    @staticmethod
+    def from_birth_death(degree, births, deaths, ess_births=np.array([]),
+                         sign_flipped=False):
+        """Returns a persistence diagram which birth and death times are given lists.
+
+        Args:
+            degree (int): The degree of the returned diagram
+            births (numpy.ndarray): The birth times
+            deaths (numpy.ndarray): The death times
+            ess_births (numpy.ndarray): The birth times of essential pairs
+            sign_flipped (bool): The sign is flipped if True
+        Returns:
+            PD: A PD object
+        """
+        return PD(None, pdgm.SimplePDGM(degree, births, deaths, ess_births, sign_flipped))
+
     def slice_histogram(self, x1, y1, x2, y2, width, bins=100):
         """Returns 1D histogram of birth-death pairs in a thin strip.
 
@@ -836,7 +874,7 @@ class Pair(object):
 
     @property
     def birth_position(self):
-        """Birth position for birth-death pairs"""
+        """Birth position for the birth-death pair"""
         return self.diagram.birth_positions[self.nth]
 
     birth_pos = property(operator.attrgetter("birth_position"))
@@ -844,7 +882,7 @@ class Pair(object):
 
     @property
     def death_position(self):
-        """Death position for birth-death pairs"""
+        """Death position for the birth-death pair"""
         return self.diagram.death_positions[self.nth]
 
     death_pos = property(operator.attrgetter("death_position"))
@@ -860,10 +898,14 @@ class Pair(object):
 
     @property
     def birth_position_symbols(self):
+        """ list of string: Birth simplex for the birth-death pair by symbols. Only available for alpha filtrations.
+        """
         return self.diagram.pd.alpha_symbol_resolver().resolve_cell(self.birth_index)
 
     @property
     def death_position_symbols(self):
+        """ list of string: Death simplex for the birth-death pair by symbols. Only available for alpha filtrations.
+        """
         return self.diagram.pd.alpha_symbol_resolver().resolve_cell(self.death_index)
 
     def optimal_volume(self, cutoff_radius=None, solver=None, solver_options=[],
@@ -947,25 +989,48 @@ class Pair(object):
 
     tightened_volume = stable_volume
 
-    def optimal_1_cycle(self):
+    def optimal_1_cycle(self, weighted=False, torelance=None):
         """Returns the optimal (not volume-optimal) 1-cycle
         corresponding to the birth-death pair.
 
-        This method is available only for a bitmap filtration.
+        You can calculate similar infomormation using :meth:`optimal_volume`, but optimal_volume
+        optimal_volume may be expensive, especiall for Vietoris-Rips filtration.
+        optimal_1_cycle can be computed at a lower cost than optimal_volume.
+        In general, an optimal volume gives better information about the birth-death pair, and
+        an optimal 1-cycle gives an approximation of the optimal volume.
 
+        This method is available only when degree == 1.
+
+        If you want to compute optimal 1-cycle. You need to pass the following argument when computing
+        persistence diagrams.
+
+        * Vietoris-Rips filtration by :meth:`PDList.from_rips_filtration`: `save_graph=True`.
+          In this case, this method returns an object of :class:`GraphOptimal1Cycle`.
+        * Alpha filtration by :meth:`PDList.from_alpha_filtration`: `save_boundary_map=True`
+          In this case, this method returns an object of :class:`Optimal1Cycle`.
+        * Abstract filtration by :meth:`PDList.from_boundary_information`: `save_boundary_map=True`.
+          In this case, this method returns an object of :class:`Optimal1Cycle`.
+        * Bitmap filtration by :meth:`PDList.from_bitmap_levelset`: `save_suppl_info=True`
+          In this case, this method returns an object of :class:`BitmapOptimal1Cycle`.
+
+        Args:
+            weighted (bool): Use graph weight to find shortest loop. Only available for Vietoris-Rips filtration
+            torelance (None or float): Noise bandwidth parameter for Reconstructed Shortest Cycles. Only available for Vietoris-Rips filtration
         Returns:
-            :class:`BitmapOptimal1Cycle`: The optimal 1-cycle.
+            :class:`BitmapOptimal1Cycle` | :class:`GraphOptimal1Cycle` | :class:`Optimal1Cycle` : The optimal 1-cycle.
 
         Raises:
             AssertionError: Raised if the filtration is not a bitmap filtration
                 or the degree of the pair is not 1.
         """
         assert self.degree == 1
-        if self.diagram.filtration_type == "bitmap":
+        if self.diagram.pd.has_chunk("graph_weights"):
+            return self.graph_optimal_1_cycle(weighted, torelance)
+        elif self.diagram.filtration_type == "bitmap":
             return self.bitmap_optimal_1_cycle()
         else:
             return self.boundary_map_optimal_1_cycle()
-        
+
     def bitmap_optimal_1_cycle(self):
         finder = pict_opt1cyc.Finder(self.diagram.pd)
         return BitmapOptimal1Cycle(finder.query_pair(self.birth_index, self.death_index))
@@ -975,6 +1040,17 @@ class Pair(object):
             self.diagram.pd.boundary_map_bytes, self.birth_index
         ))
 
+    def graph_optimal_1_cycle(self, weighted=False, torelance=None):
+        if torelance is None:
+            return GraphOptimal1Cycle(self, graph_opt1cyc.search(
+                self.diagram.pd.graph_adjacent_matrix, self.birth_time(), weighted
+            ))
+        else:
+            return GraphOptimal1Cycle(self, graph_opt1cyc.search_with_cocycle(
+                self.diagram.pd.graph_adjacent_matrix, self.representative_cocycle(),
+                self.birth_time(), torelance, weighted
+            ))
+
     def __eq__(self, other):
         return (isinstance(other, Pair) and
                 self.diagram == other.diagram and
@@ -994,6 +1070,9 @@ class Pair(object):
     def __hash__(self):
         return(id(self.diagram) + (int(self.nth) << 20))
 
+    def representative_cocycle(self):
+        return self.diagram.pd.representative_cocycle(self.degree, self.nth)
+
     @property
     def degree(self):
         """The degree of the pair.
