@@ -67,10 +67,6 @@ def sign_function(boundary_map):
     raise(RuntimeError("Unknown maptype: {}".format(boundary_map["type"])))
 
 
-def build_subvolume_boundary_matrix(optimal_volume, threshold):
-    pass
-
-
 class Optimizer(object):
     def __init__(self, birth, death, boundary_map, lp_solver):
         self.birth = birth
@@ -152,6 +148,7 @@ class Success(object):
         self.pair = None
         self.subvolume = None
 
+    success = True
     infeasible = False
 
     def children(self, death, death_to_birth):
@@ -187,6 +184,8 @@ class Failure(object):
         self.status = status
         self.pair = None
 
+    success = False
+
     @property
     def infeasible(self):
         # NOTE: GLPK solver returns pulp.LpStatusUndefined when a problem is infeasible.
@@ -370,7 +369,7 @@ class OptimalVolumeTightenedSubVolumeFinder(object):
 
     def find(self, birth, death):
         optimal_volume = self.optimizer_builder.build(birth, death).find()
-        if not isinstance(optimal_volume, Success):
+        if not optimal_volume.success:
             return optimal_volume
         optimal_volume.subvolume = self.tsv_finder.find(
             birth, death, optimal_volume.cell_indices
@@ -434,7 +433,7 @@ class RectangleQuery(object):
         for pair_indices, pair in self.pairs_in_rectangle():
             result = self.ovfinder.find(*pair_indices)
             result.pair = pair
-            if isinstance(result, Success):
+            if result.success:
                 results.append(result)
             elif result.infeasible and self.skip_infeasible:
                 results.append(result)
@@ -794,7 +793,7 @@ class Main(object):
 
     def build_jsondict(self, query, results):
         def result_to_dict(result):
-            if isinstance(result, Success):
+            if result.success:
                 return self.success_to_dict(result)
             else:
                 return failure_to_dict(result)
@@ -802,7 +801,7 @@ class Main(object):
         return {
             "format-version": 2.0,
             "query": query.to_dict(),
-            "results": [result_to_dict(r) for r in results]
+            "result": [result_to_dict(r) for r in results]
         }
 
     def invoke_paraview(self, results):
