@@ -10,17 +10,31 @@ def empty_pd(degree=0, sign_flipped=False):
     return SimplePDGM(degree, empty_array, empty_array, empty_array, sign_flipped)
 
 
-class SimplePDGM(object):
+class PDGMBase(object):
+    def minmax_of_birthdeath_time(self):
+        return (min(self.births.min(), self.deaths.min()),
+                max(self.births.max(), self.deaths.max()))
+
+    def count_pairs_in_rectangle(self, birth1, birth2, death1, death2):
+        birth_min = min([birth1, birth2])
+        birth_max = max([birth1, birth2])
+        death_min = min([death1, death2])
+        death_max = max([death1, death2])
+        return np.sum((self.births >= birth_min) & (self.births <= birth_max) &
+                      (self.deaths >= death_min) & (self.deaths <= death_max))
+
+
+class SimplePDGM(PDGMBase):
     def __init__(self, degree, births, deaths, ess_births=np.array([]),
                  sign_flipped=False):
         self.degree = degree
         self.births = births
         self.deaths = deaths
         self.essential_births = ess_births
-        self.sign_flipped = False
+        self.sign_flipped = sign_flipped
 
 
-class PDGM(object):
+class PDGM(PDGMBase):
     def __init__(self, reader, degree, load_indexed_pairs=True):
         self.pdgmreader = reader
         self.degree = degree
@@ -44,6 +58,9 @@ class PDGM(object):
         self.death_indices = np.array(deaths, dtype=int)
         self.essential_birth_indices = np.array(ess_births, dtype=int)
 
+    def has_chunk(self, chunktype, degree=None):
+        return self.pdgmreader.find_chunk_metadata(chunktype, degree) is not None
+
     @staticmethod
     def open(path, degree, load_indexed_pairs=True):
         return PDGM(PDGMReader.open(path), degree, load_indexed_pairs)
@@ -106,18 +123,6 @@ class PDGM(object):
     def index_to_simplex(self):
         return self.pdgmreader.load_simple_chunk("index_to_simplex")
 
-    def minmax_of_birthdeath_time(self):
-        return (min(self.births.min(), self.deaths.min()),
-                max(self.births.max(), self.deaths.max()))
-
-    def count_pairs_in_rectangle(self, birth1, birth2, death1, death2):
-        birth_min = min([birth1, birth2])
-        birth_max = max([birth1, birth2])
-        death_min = min([death1, death2])
-        death_max = max([death1, death2])
-        return np.sum((self.births >= birth_min) & (self.births <= birth_max) &
-                      (self.deaths >= death_min) & (self.deaths <= death_max))
-
     @cached_property
     def boundary_map_chunk(self):
         return self.pdgmreader.load_boundary_map_chunk()
@@ -134,7 +139,11 @@ class PDGM(object):
 
     @cached_property
     def num_vertices(self):
-        return self.pdgmreader.load_chunk("alpha_information")["num_vertices"]
+        if self.filtration_type == "alpha":
+            return self.pdgmreader.load_chunk("alpha_information")["num_vertices"]
+        if self.filtration_type == "rips":
+            print(self.pdgmreader.load_chunk("rips_information"))
+            return self.pdgmreader.load_chunk("rips_information")["num_vertices"]
 
     def simplicial_symbol_resolver(self):
         assert self.filtration_type in ["alpha", "simplicial"]
@@ -179,6 +188,14 @@ class PDGM(object):
             self.boundary_map
         )
 
+    def rips_geometry_resolver(self):
+        assert self.filtration_type == "rips"
+
+        return geom_resolver.RipsResolver(
+            self.pdgmreader.load_simple_chunk("vertex_symbols") or
+            self.default_vertex_symbols()
+        )
+
     def geometry_resolver(self, use_symbol):
         if self.filtration_type == "alpha":
             if use_symbol:
@@ -193,6 +210,8 @@ class PDGM(object):
             return self.bitmap_geometry_resolver()
         elif self.filtration_type == "abstract":
             return self.abstract_geometry_resolver()
+        elif self.filtration_type == "rips":
+            return self.rips_geometry_resolver()
         else:
             raise(RuntimeError("Geometry resolver is unavailable for {}".format(
                 self.filtration_type
@@ -222,3 +241,18 @@ class PDGM(object):
     def pairs_positions(self):
         return zip(self.births, self.deaths,
                    self.birth_positions, self.death_positions)
+
+    @property
+    def graph_adjacent_matrix(self):
+        chunk = self.pdgmreader.load_chunk("graph_weights")
+        if chunk is None:
+            return None
+        num_vertices = chunk["num_vertices"]
+        matrix = np.zeros((num_vertices, num_vertices), dtype=float)
+        xs, ys = np.triu_indices(num_vertices, 1)
+        matrix[(xs, ys)] = chunk["weights"]
+        matrix[(ys, xs)] = chunk["weights"]
+        return matrix
+
+    def representative_cocycle(self, d, nth):
+        return self.pdgmreader.load_simple_chunk("cocycles", d)[nth]
