@@ -4,7 +4,7 @@ import struct
 from pathlib import Path
 
 from cached_property import cached_property
-
+import numpy as np
 
 MAGIC_HEADER = (b"HomCloud .pdgm format" + b"\0" * 24)[0:24]
 MAGIC_HEADER_LENGTH = len(MAGIC_HEADER)
@@ -136,6 +136,23 @@ class AlphaInformationChunk(object):
         }
 
 
+class RipsInformationChunk(object):
+    def __init__(self, num_vertices):
+        self.num_vertices = num_vertices
+
+    @cached_property
+    def binary(self):
+        return msgpack.packb({
+            "chunktype": "rips_information",
+            "num_vertices": self.num_vertices
+        })
+
+    def metadata(self, start):
+        return {
+            "chunktype": "rips_information", "start": start, "length": len(self.binary)
+        }
+
+
 class BoundaryMapChunk(object):
     def __init__(self, type, map):
         self.type = type
@@ -153,6 +170,31 @@ class BoundaryMapChunk(object):
         }
 
 
+class GraphWeightsChunk(object):
+    def __init__(self, matrix):
+        assert matrix.ndim == 2 and matrix.shape[0] == matrix.shape[1]
+        self.matrix = matrix
+
+    @cached_property
+    def binary(self):
+        return msgpack.packb({
+            "chunktype": "graph_weights", "num_vertices": self.num_vertices,
+            "weights": self.graph_weights(),
+        })
+
+    def graph_weights(self):
+        return self.matrix[np.triu_indices(self.num_vertices, 1)].tolist()
+
+    @property
+    def num_vertices(self):
+        return self.matrix.shape[0]
+
+    def metadata(self, start):
+        return {
+            "chunktype": "graph_weights", "start": start, "length": len(self.binary)
+        }
+
+
 class PDGMWriter(object):
     def __init__(self, out, filtration_type, dim=None):
         self.out = out
