@@ -14,7 +14,7 @@ from PyQt5.QtCore import QCoreApplication, Qt, QTimer, QProcess
 from PyQt5.QtGui import QIcon, QCursor, QPixmap
 import numpy as np
 import matplotlib
-matplotlib.use("Qt5Agg")
+matplotlib.use("Qt5Agg")  # noqa
 from matplotlib.backends.backend_qt5agg import (
     FigureCanvasQTAgg as FigureCanvas,
     NavigationToolbar2QT as NavigationToolbar
@@ -29,10 +29,13 @@ from homcloud.plot_PD import (
     add_arguments_for_auxinfo, add_arguments_for_zspec,
     AuxPlotInfo, ZSpec, PDColorHistogramPlotter, PDContourPlotter
 )
+from homcloud.argparse_common import (
+    add_arguments_for_load_diagrams, add_arguments_for_histogram_rulers, parse_bool
+)
 import homcloud.utils as utils
-import homcloud.resources   # noqa: F401
+import homcloud.resources  # noqa
 from homcloud.version import __version__
-from homcloud.diagram import Ruler, PDHistogram
+from homcloud.histogram import Ruler, PDHistogram
 import homcloud.full_ph_tree as full_ph_tree
 from homcloud.index_map import MapType
 from homcloud.diagram import PD
@@ -269,7 +272,7 @@ class MainWindow(QMainWindow):
     @staticmethod
     def slider_to_value(val, range_):
         left, right = range_
-        return left + val/100.0*(right - left)
+        return left + val / 100.0 * (right - left)
 
     def adjust_editline_by_slider(self, slider, editline, range_):
         editline.setText(str(self.slider_to_value(slider.value(), range_)))
@@ -302,7 +305,7 @@ class MainWindow(QMainWindow):
     @staticmethod
     def value_to_slider(val, range_):
         left, right = range_
-        return int(100*(val - left)/(right - left))
+        return int(100 * (val - left) / (right - left))
 
     def canvas_event_handlers(self):
         return [
@@ -1033,7 +1036,7 @@ def argument_parser():
     p = argparse.ArgumentParser(description="View PD interactively",
                                 conflict_handler='resolve')
     p.add_argument("-V", "--version", action="version", version=__version__)
-    utils.add_arguments_for_load_diagrams(p)
+    add_arguments_for_load_diagrams(p)
     p.add_argument("--power", default=None,
                    help="colorbar scale: x^POWER for each value x")
     p.add_argument("-l", "--log", action="store_true", default=False,
@@ -1044,13 +1047,13 @@ def argument_parser():
                    help="Maximum of colorbar (default: autoscale)")
     p.add_argument("-c", "--colormap", default="",
                    help="matplotlib colormap name")
-    utils.add_arguments_for_histogram_rulers(p)
+    add_arguments_for_histogram_rulers(p)
     add_arguments_for_auxinfo(p)
     p.add_argument("-n", "--normalize-constant", type=float, default=1.0,
                    help="normalize constant to histogram height")
     p.add_argument("-p", "--ph-trees", help="ph trees file (.pht)")
     p.add_argument("--optimal-volume", "--optimal-cycle",
-                   default=False, type=utils.parse_bool,
+                   default=False, type=parse_bool,
                    help="activate optimal volume (on/off)")
     p.add_argument("--optimal-volume-options", default="",
                    help="options for optimal_volume module")
